"""
MCP Clients

A Python package for creating Model Context Protocol (MCP) clients that integrate
with various AI models and services.

This package provides easy-to-use clients for connecting to MCP servers and 
facilitating communication between AI models and external tools/services.

Classes:
    Gemini: A client for Google's Gemini AI model with MCP server integration

Example:
    >>> import asyncio
    >>> from mcp_clients import Gemini
    >>> 
    >>> async def main():
    ...     client = await Gemini.init(
    ...         server_script_path='path/to/your/mcp_server.py',
    ...         system_instruction='You are a helpful assistant.'
    ...     )
    ...     try:
    ...         await client.chat_loop()
    ...     finally:
    ...         await client.cleanup()
    >>> 
    >>> asyncio.run(main())

Author: Muhammad Faiz Raza
Version: 0.0.2
"""

from .gemini import Gemini
from .version import __version__

__all__ = ["Gemini", "__version__"]
